﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class MobileMaster : System.Web.UI.MasterPage
{

    #region " Default Values, DefaultValueCheck, ResetToDefaults "
    public const double default_lat = 38.576691;
    public const double default_lng = -121.495012;
    public const string default_cty = "Sacramento";

    public void DefaultValueCheck()
    {
        if (PersistanceDataSupport.GetPersistanceValue<bool>("UserLocationSet", true) == null)
        {
            ResetToDefaults();
        }
    }

    public void ResetToDefaults()
    {
        data_UserLocationSet = false;
        data_Lat = default_lat;
        data_Lng = default_lng;
        data_Cty = default_cty;
    }
    #endregion

    #region " IsHomePage, BackButtonURL, PageBody, PageTitle, MapScriptEnabled "
    /// <summary>
    /// True if the current page should display headers and footers associated with the home page
    /// </summary>
    public bool IsHomePage { get; set; }

    public System.Web.UI.HtmlControls.HtmlGenericControl PageBody
    {
        get { return MyPageBody; }
    }

    public string PageTitle
    {
        get { return Page.Title; }
        set
        {
            Page.Title = value;
        }
    }

    public bool MapScriptEnabled
    {
        get { return litMapScript.Visible; }
        set { litMapScript.Visible = value; }
    }
    #endregion

    #region " data_Lat, data_Lng, data_Cty, data_UserLocationSet "

    public double data_Lat
    {
        get
        {
            DefaultValueCheck();

            return PersistanceDataSupport.GetPersistanceValue<double>("lat", true).Value;
        }
        set
        {
            //Validation
            if (value < 32 || value > 42)
            {
                ResetToDefaults();
            }
            else
            {
                PersistanceDataSupport.SetSessionValue<double>("lat", value);
            }
        }
    }

    public double data_Lng
    {
        get
        {
            DefaultValueCheck();

            return PersistanceDataSupport.GetPersistanceValue<double>("lng", true).Value;
        }
        set
        {
            //Validation
            if (value < -124 || value > -114)
            {
                ResetToDefaults();
            }
            else
            {
                PersistanceDataSupport.SetSessionValue<double>("lng", value);
            }
        }
    }

    public string data_Cty
    {
        get
        {
            DefaultValueCheck();

            return PersistanceDataSupport.GetPersistanceValue("cty", true);
        }
        set { PersistanceDataSupport.SetSessionValue("cty", value); }
    }

    public bool data_UserLocationSet
    {
        get
        {
            DefaultValueCheck();

            return PersistanceDataSupport.GetPersistanceValue<bool>("UserLocationSet", true).Value;
        }
        set { PersistanceDataSupport.SetSessionValue<bool>("UserLocationSet", value); }
    }
    #endregion

    #region " Page_Init "
    private void Page_Init(object sender, System.EventArgs e) //AutoWireup
    {
        MobileRedirection();

        if (Request.QueryString["lat"] != null && Request.QueryString["lng"] != null)
        {
            //Override lat/long
            string sql = string.Format(Resources.SqlQueries.sqlCityLookup, Resources.SqlQueries.TableCity, data_Lat, data_Lng);
            System.Data.DataTable dt = GoogleFusionSupport.gftExecuteWithRetry(sql);

            data_Cty = (string)dt.Rows[0]["CITY"];
            data_UserLocationSet = true;

        }

        //Apply the Google API Maps key
        litMapScript.Text = string.Format(litMapScript.Text, Resources.SqlQueries.GoogleApiKey);
    }
    #endregion

    #region " Page_PreRender "
    private void Page_PreRender(object sender, System.EventArgs e) //AutoWireup
    {
        MyPageBody.Attributes["id"] = IsHomePage ? "home" : "second";

        phSecondaryPageHeader.Visible = !IsHomePage;
        phHomeFooter.Visible = IsHomePage;
        phBackToTop.Visible = !phHomeFooter.Visible;
        phHomeHeader.Visible = IsHomePage;
        phHomeTitle.Visible = IsHomePage;

        if (data_UserLocationSet)
        {
            lnkLocation.InnerText = data_Cty;
        }

        Page.PreRenderComplete += Page_PreRenderComplete;
    }

    private void Page_PreRenderComplete(object sender, System.EventArgs e)
    {
        RemoveIDs(this.Controls);
    }

    /// <summary>
    /// Removes IDs from the page.  Don't use this if you require client script access to server controls.
    /// </summary>
    /// <param name="Controls">Page.Controls</param>
    private static void RemoveIDs(System.Web.UI.ControlCollection Controls)
    {
        foreach (System.Web.UI.Control oControl in Controls)
        {
            oControl.ID = "";

            RemoveIDs(oControl.Controls);
        }
    }
    #endregion

    private static void MobileRedirection()
    {
	    //	* * * * * * * * * * * * * * * * * * * *
	    //	*   M O B I L E   D E T E C T I O N   *
	    //	* * * * * * * * * * * * * * * * * * * *	

	    //	D I S A B L E   M O B I L E   D E T E C T I O N 
	    if (HttpContext.Current.Request.QueryString["detect"] == "disable") {
		    HttpContext.Current.Session["detect"] = HttpContext.Current.Request.QueryString["detect"];
	    }


	    //	V A L I D A T E   M O B I L E   D E T E C T I O N
	    if (HttpContext.Current.Session["detect"] != "enable" && HttpContext.Current.Session["detect"] != "disable") {
		    HttpContext.Current.Session["detect"] = "enable";
	    }

	    //	M O B I L E   D E T E C T I O N 
	    string ua = HttpContext.Current.Request.ServerVariables["HTTP_USER_AGENT"].ToLower();


	    if (HttpContext.Current.Session["detect"] == "enable") {
		    string[] devices = new string[] {
			    "iphone",
			    "android",
			    "windows phone",
			    "blackberry"
		    };

		    if ((from x in devices where ua.Contains(x) select x).Any()) {
			    HttpContext.Current.Response.Redirect("http://m.ca.gov");
		    }
	    }
    }

}
