﻿#Region "CompilerDefaults"
Option Strict On
Option Explicit On
Option Infer On
Option Compare Binary
#End Region

Public Class GoogleFusionSupport

#Region " gftExecuteWithRetry "
    ''' <summary>
    ''' Execute a query using Google Fusion tables.  Automatically retry the query 5 times.
    ''' </summary>
    ''' <param name="SqlQuery">The SQL Query to execute</param>
    Public Overloads Shared Function gftExecuteWithRetry(SqlQuery As String) As Data.DataTable
        For retry_count = 0 To 5
            Try
                Return gftExecuteOnce(SqlQuery)
            Catch
                'whatever...try again
            End Try
        Next

        'No just crash normally
        Return gftExecuteOnce(SqlQuery)
    End Function

    ''' <summary>
    ''' Execute a query using Google Fusion tables.  Automatically retry the query 5 times.
    ''' </summary>
    ''' <typeparam name="T">The typed datatable type to use</typeparam>
    ''' <param name="SqlQuery">The SQL Query to execute</param>
    Public Overloads Shared Function gftExecuteWithRetry(Of T As {Data.DataTable, New})(SqlQuery As String) As T
        Dim dtBase = gftExecuteWithRetry(SqlQuery)

        Dim dtTyped As New T
        dtTyped.Merge(dtBase)

        Return dtTyped
    End Function

    Private Shared Function gftExecuteOnce(SqlQuery As String) As Data.DataTable
        Dim gft As New GoogleFusionTableWrapperNET.FusionTableWrapper(Resources.SqlQueries.GoogleApiKey)

        Return gft.ExecuteQuery(SqlQuery)
    End Function
#End Region
End Class