﻿#Region " Compiler Options "
Option Strict On
Option Explicit On
Option Compare Binary
Option Infer On
#End Region

Partial Class MobileMaster
    Inherits System.Web.UI.MasterPage

#Region " Default Values, DefaultValueCheck, ResetToDefaults "
    Public Const default_lat As Double = 38.576691
    Public Const default_lng As Double = -121.495012
    Public Const default_cty As String = "Sacramento"

    Public Sub DefaultValueCheck()
        If PersistanceDataSupport.GetPersistanceValue(Of Boolean)("UserLocationSet", True) Is Nothing Then
            ResetToDefaults()
        End If
    End Sub

    Public Sub ResetToDefaults()
        data_UserLocationSet = False
        data_Lat = default_lat
        data_Lng = default_lng
        data_Cty = default_cty
    End Sub
#End Region

#Region " IsHomePage, BackButtonURL, PageBody, PageTitle, MapScriptEnabled "
    ''' <summary>
    ''' True if the current page should display headers and footers associated with the home page
    ''' </summary>
    Public Property IsHomePage As Boolean
        Get
            Return _IsHomePage
        End Get
        Set(value As Boolean)
            _IsHomePage = value
        End Set
    End Property
    Private _IsHomePage As Boolean = False

    Public ReadOnly Property PageBody As Web.UI.HtmlControls.HtmlGenericControl
        Get
            Return MyPageBody
        End Get
    End Property

    Public Property PageTitle As String
        Get
            Return Page.Title
        End Get
        Set(value As String)
            Page.Title = value
        End Set
    End Property

    Public Property MapScriptEnabled As Boolean
        Get
            Return litMapScript.Visible
        End Get
        Set(value As Boolean)
            litMapScript.Visible = value
        End Set
    End Property
#End Region

#Region " data_Lat, data_Lng, data_Cty, data_UserLocationSet "
    Public Property data_Lat As Double
        Get
            DefaultValueCheck()

            Return PersistanceDataSupport.GetPersistanceValue(Of Double)("lat", True).Value
        End Get
        Set(value As Double)
            'Validation
            If value < 32 OrElse value > 42 Then
                ResetToDefaults()
            Else
                PersistanceDataSupport.SetSessionValue("lat", value)
            End If
        End Set
    End Property

    Public Property data_Lng As Double
        Get
            DefaultValueCheck()

            Return PersistanceDataSupport.GetPersistanceValue(Of Double)("lng", True).Value
        End Get
        Set(value As Double)
            'Validation
            If value < -124 OrElse value > -114 Then
                ResetToDefaults()
            Else
                PersistanceDataSupport.SetSessionValue("lng", value)
            End If
        End Set
    End Property

    Public Property data_Cty As String
        Get
            DefaultValueCheck()

            Return PersistanceDataSupport.GetPersistanceValue("cty", True)
        End Get
        Set(value As String)
            PersistanceDataSupport.SetSessionValue("cty", value)
        End Set
    End Property

    Public Property data_UserLocationSet As Boolean
        Get
            DefaultValueCheck()

            Return PersistanceDataSupport.GetPersistanceValue(Of Boolean)("UserLocationSet", True).Value
        End Get
        Set(value As Boolean)
            PersistanceDataSupport.SetSessionValue("UserLocationSet", value)
        End Set
    End Property
#End Region

#Region " Page_Init "
    Private Sub Page_Init(sender As Object, e As System.EventArgs) 'AutoWireup
        MobileRedirection()

        If Request.QueryString("lat") IsNot Nothing AndAlso Request.QueryString("lng") IsNot Nothing Then
            'Override lat/long
            Dim sql = String.Format(Resources.SqlQueries.sqlCityLookup, Resources.SqlQueries.TableCity, data_Lat, data_Lng)
            Dim dt = GoogleFusionSupport.gftExecuteWithRetry(sql)

            data_Cty = DirectCast(dt.Rows(0)("CITY"), String)
            data_UserLocationSet = True
        End If

        'Apply the Google API Maps key
        litMapScript.Text = String.Format(litMapScript.Text, Resources.SqlQueries.GoogleApiKey)
    End Sub
#End Region

#Region " Page_PreRender, Page_PreRenderComplete, RemoveIDs "
    Private Sub Page_PreRender(sender As Object, e As System.EventArgs) 'AutoWireup
        MyPageBody.Attributes("id") = If(IsHomePage, "home", "second")

        phSecondaryPageHeader.Visible = Not IsHomePage
        phHomeFooter.Visible = IsHomePage
        phBackToTop.Visible = Not phHomeFooter.Visible
        phHomeHeader.Visible = IsHomePage
        phHomeTitle.Visible = IsHomePage

        If data_UserLocationSet Then
            lnkLocation.InnerText = data_Cty
        End If

        AddHandler Page.PreRenderComplete, AddressOf Page_PreRenderComplete
    End Sub

    Private Sub Page_PreRenderComplete(sender As Object, e As System.EventArgs)
        RemoveIDs(Me.Controls)
    End Sub

    ''' <summary>
    ''' Removes IDs from the page.  Don't use this if you require client script access to server controls.
    ''' </summary>
    ''' <param name="Controls">Page.Controls</param>
    Private Shared Sub RemoveIDs(Controls As Web.UI.ControlCollection)
        For Each oControl In Controls.Cast(Of System.Web.UI.Control)()
            oControl.ID = ""

            RemoveIDs(oControl.Controls)
        Next
    End Sub
#End Region

#Region " MobileRedirection "
    Private Shared Sub MobileRedirection()
        '	* * * * * * * * * * * * * * * * * * * *
        '	*   M O B I L E   D E T E C T I O N   *
        '	* * * * * * * * * * * * * * * * * * * *	

        '	D I S A B L E   M O B I L E   D E T E C T I O N 
        If HttpContext.Current.Request.QueryString("detect") = "disable" Then
            HttpContext.Current.Session("detect") = HttpContext.Current.Request.QueryString("detect")
        End If


        '	V A L I D A T E   M O B I L E   D E T E C T I O N
        Select Case DirectCast(HttpContext.Current.Session("detect"), String)
            Case "enable", "disable"
                'Don't touch it
            Case Else
                HttpContext.Current.Session("detect") = "enable"
        End Select

        '	M O B I L E   D E T E C T I O N 
        Dim ua = HttpContext.Current.Request.ServerVariables("HTTP_USER_AGENT").ToLower

        If DirectCast(HttpContext.Current.Session("detect"), String) = "enable" Then

            Dim devices = New String() {"iphone", "android", "windows phone", "blackberry"}

            If (From x In devices Where ua.Contains(x)).Any Then
                HttpContext.Current.Response.Redirect("http://m.ca.gov")
            End If
        End If
    End Sub
#End Region
End Class